netapp_ontap.models.application_nfs_properties API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.application_nfs_properties`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ApplicationNfsPropertiesSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ApplicationNfsProperties object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `backing_storage: ApplicationCifsPropertiesBackingStorage GET`

    The backing_storage field of the application_nfs_properties.

  `export_policy: ApplicationNfsPropertiesExportPolicy GET`

    The export_policy field of the application_nfs_properties.

  `ips: List[str] GET POST PATCH`

    The ips field of the application_nfs_properties.

  `path: str GET`

    Junction path

  `permissions: List[ApplicationNfsPropertiesPermissions] GET`

    The permissions field of the application_nfs_properties.